@@ -204,10 +204,19 @@ sub style_text {
             }
 
             if ($color_element && $options{color}) {
+                my $ns = $color_element->namespaceURI;
+
                 $color_element->setAttributeNS(
-                    $color_element->namespaceURI,
+                    $ns,
                     'val' => $color_to_set
                 );
+
+                # We're explicitly setting the color, so we need to remove
+                # the "document theme"-based color attributes or they'll
+                # take precedence.
+                $color_element->removeAttributeNS($ns => 'themeColor');
+                $color_element->removeAttributeNS($ns => 'themeShade');
+                $color_element->removeAttributeNS($ns => 'themeTint');
             }
 
             if ($color_element && not defined $options{color}) {
@@ -524,7 +533,7 @@ Document::OOXML::Part::WordprocessingML - WordprocessingML document part handlin
 
 =head1 VERSION
 
-version 0.180742
+version 0.180750
 
 =head1 ATTRIBUTES
 
